@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2022-04-24 15:15:19
-@LastEditTime: 2022-11-24 18:59:29
+@LastEditTime: 2022-11-25 09:19:23
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -333,14 +333,13 @@ class FrameBaseHandler(BaseApiHandler):
         """
         self.response_common(data=data,is_close_encrypt=is_close_encrypt)
 
-    def response_json_error(self, error_code="", error_message="", data=None, log_type=0, is_close_encrypt=False):
+    def response_json_error(self, error_code="", error_message="", data=None, log_type=0):
         """
         :description: 通用错误返回json结构
         :param errorCode: 字符串，调用失败（success为false）时，服务端返回的错误码
         :param errorMessage: 字符串，调用失败（success为false）时，服务端返回的错误信息
         :param data: 返回结果对象，即为数组，字典
         :param log_type: 日志记录类型（0-不记录，1-info，2-error）
-        :param is_close_encrypt: 是否关闭输出加密（True-是 False-否）
         :return: 将dumps后的数据字符串返回给客户端
         :last_editors: HuangJianYi
         """
@@ -348,7 +347,7 @@ class FrameBaseHandler(BaseApiHandler):
             self.logging_link_info(f"{error_code}\n{error_message}\n{data}\n{self.request}")
         elif log_type == 2:
             self.logging_link_error(f"{error_code}\n{error_message}\n{data}\n{self.request}")
-        self.response_common(False, data, error_code, error_message, is_close_encrypt)
+        self.response_common(False, data, error_code, error_message)
 
     def response_json_error_params(self):
         """
