@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 11:30:45
-@LastEditTime: 2022-11-21 17:15:55
+@LastEditTime: 2022-12-01 11:30:13
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -30,12 +30,11 @@ class OSS2Helper:
             oss_config["bucket_name"] = "mang-he"
             oss_config["end_point"] = "oss-cn-zhangjiakou.aliyuncs.com"
             oss_config["demain"] = "https://mang-he.oss-cn-zhangjiakou.aliyuncs.com/"
-        self.ak_id = oss_config["ak_id"]
-        self.ak_secret = oss_config["ak_secret"]
-        self.bucket_name = oss_config["bucket_name"]
-        self.end_point = oss_config["end_point"]
-        self.demain = oss_config["demain"]
-
+        self.ak_id = oss_config.get("ak_id","")
+        self.ak_secret = oss_config.get("ak_secret","")
+        self.bucket_name = oss_config.get("bucket_name","")
+        self.end_point = oss_config.get("end_point","")
+        self.demain = oss_config.get("demain","")
     @classmethod
     def upload(self, file_name, local_file='', folder='', is_auto_name=True, data=None):
         """
