@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-19 09:23:14
-@LastEditTime: 2022-11-25 09:11:34
+@LastEditTime: 2022-11-30 09:35:31
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -178,12 +178,11 @@ class WeChatHelper:
             return invoke_result_data
 
     @classmethod
-    def get_share_sign_package(self, request_url, app_id="", app_secret=""):
+    def get_share_sign_package(self, request_url, app_id=""):
         """
         :description:获取分享请求参数
         :param request_url:请求地址
         :param app_id:app_id
-        :param app_secret:app_secret
         :return: 返回分享请求参数
         :last_editors: HuangJianYi
         """
@@ -433,24 +432,24 @@ class WeChatHelper:
             return invoke_result_data
 
     @classmethod
-    def create_qr_code(self, page, scene="a=1", width=430, app_id="", app_secret="", no_limit_code=True):
+    def create_qr_code_unlimit(self, page, scene="a=1", width=430, env_version="release", app_id="", app_secret=""):
         """
         :description:获取小程序/小游戏的二维码（注意：接口只能生成已发布的小程序的二维码。开发版的带参二维码可以在开发者工具预览时生成）
         :param page: 页面 page，例如 pages/index/index，根路径前不要填加 /，不能携带参数（参数请放在scene字段里），如果不填写这个字段，默认跳主页面
         :param scene: 最大32个可见字符，只支持数字，大小写英文以及部分特殊字符：!#$&'()*+,/:;=?@-._~，其它字符请自行编码为合法字符（因不支持%，中文无法使用 urlencode 处理，请使用其他编码方式）
         :param width: 二维码的宽度，单位 px，最小 280px，最大 1280px
+        :param env_version: 要打开的小程序版本。正式版为 "release"，体验版为 "trial"，开发版为 "develop"。默认是正式版。
         :param app_id:app_id
         :param app_secret:app_secret
-        :param no_limit_code:是否无限制小程序码
         :return: 图片二进制 数据类型Array<byte>
         :last_editors: HuangJianYi
         """
         app_id = app_id if app_id else config.get_value("app_id")
         app_secret = app_secret if app_secret else config.get_value("app_secret")
-        
+
         invoke_result_data = InvokeResultData()
         redis_init = SevenHelper.redis_init(decode_responses=False)
-        redis_key = "wechat_qr_code:" + CryptoHelper.md5_encrypt(f"{page}_{scene}")
+        redis_key = "create_qr_code_unlimit:" + CryptoHelper.md5_encrypt(f"{page}_{scene}")
         redis_value = redis_init.get(redis_key)
         if redis_value:
             invoke_result_data.data = redis_value
@@ -470,12 +469,8 @@ class WeChatHelper:
         response = ""
         try:
             headers = {"Content-type": "application/json"}
-            if no_limit_code == True:
-                requset_url = 'https://api.weixin.qq.com/wxa/getwxacodeunlimit?access_token=' + access_token
-                param = {"scene": scene, "page": page, "width": width}
-            else:
-                requset_url = 'https://api.weixin.qq.com/cgi-bin/wxaapp/createwxaqrcode?access_token=' + access_token
-                param = {"path": page, "width": width}
+            requset_url = 'https://api.weixin.qq.com/wxa/getwxacodeunlimit?access_token=' + access_token
+            param = {"page": page, "scene": scene, "width": width, "env_version": env_version}
             try:
                 response = requests.post(requset_url, data=json.dumps(param, ensure_ascii=False).encode('utf-8'), headers=headers)
                 response_data = SevenHelper.json_loads(response.text)
@@ -487,7 +482,65 @@ class WeChatHelper:
             except:
                 pass
             invoke_result_data.data = response.content
-            redis_init.set(redis_key, response.content, 30*24*3600)
+            redis_init.set(redis_key, response.content, 30 * 24 * 3600)
+            return invoke_result_data
+        except Exception as ex:
+            self.logger_error.error("【create_qr_code_unlimit】" + traceback.format_exc() + ":" + str(response.text))
+            invoke_result_data.success = False
+            invoke_result_data.error_code = "exception"
+            invoke_result_data.error_message = traceback.format_exc()
+            return invoke_result_data
+
+    @classmethod
+    def create_qr_code(self, path, width=430, app_id="", app_secret=""):
+        """
+        :description:获取小程序二维码，适用于需要的码数量较少的业务场景。通过该接口生成的小程序码，永久有效，有数量限制
+        :param path: 扫码进入的小程序页面路径，最大长度 128 字节，不能为空；对于小游戏，可以只传入 query 部分，来实现传参效果，如：传入 "?foo=bar"，即可在 wx.getLaunchOptionsSync 接口中的 query 参数获取到 {foo:"bar"}。
+        :param width: 二维码的宽度，单位 px，最小 280px，最大 1280px
+        :param app_id:app_id
+        :param app_secret:app_secret
+        :return: 图片二进制 数据类型Array<byte>
+        :last_editors: HuangJianYi
+        """
+        app_id = app_id if app_id else config.get_value("app_id")
+        app_secret = app_secret if app_secret else config.get_value("app_secret")
+
+        invoke_result_data = InvokeResultData()
+        redis_init = SevenHelper.redis_init(decode_responses=False)
+        redis_key = "wechat_qr_code:" + CryptoHelper.md5_encrypt(f"{path}")
+        redis_value = redis_init.get(redis_key)
+        if redis_value:
+            invoke_result_data.data = redis_value
+            return invoke_result_data
+
+        for i in range(2):
+            if i == 0:
+                invoke_result_data = self.get_access_token(app_id, app_secret)
+            else:
+                invoke_result_data = self.get_access_token(app_id, app_secret, True)
+
+            if invoke_result_data.success == True:
+                break
+        if invoke_result_data.success == False:
+            return invoke_result_data
+        access_token = invoke_result_data.data
+        response = ""
+        try:
+            headers = {"Content-type": "application/json"}
+            requset_url = 'https://api.weixin.qq.com/cgi-bin/wxaapp/createwxaqrcode?access_token=' + access_token
+            param = {"path": path, "width": width}
+            try:
+                response = requests.post(requset_url, data=json.dumps(param, ensure_ascii=False).encode('utf-8'), headers=headers)
+                response_data = SevenHelper.json_loads(response.text)
+                if response_data.__contains__("errcode") and response_data["errcode"] != 0:
+                    invoke_result_data.success = False
+                    invoke_result_data.error_code = response_data["errcode"]
+                    invoke_result_data.error_message = response_data["errmsg"]
+                    return invoke_result_data
+            except:
+                pass
+            invoke_result_data.data = response.content
+            redis_init.set(redis_key, response.content, 30 * 24 * 3600)
             return invoke_result_data
         except Exception as ex:
             self.logger_error.error("【create_qr_code】" + traceback.format_exc() + ":" + str(response.text))
