@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-11-24 09:36:39
-@LastEditTime: 2022-10-25 17:49:37
+@LastEditTime: 2022-11-15 15:02:38
 @LastEditors: HuangJianYi
 @Description: ERP控制台业务模型(用于跟遁甲系统对接，推送订单和回写物流) 需在配置文件加 armor_url 和 armor_sign_key对应的值
 """
@@ -22,27 +22,30 @@ class ErpConsoleModel():
     """
     :description: ERP控制台业务模型(用于跟遁甲系统对接，推送订单和回写物流)
     """
-    def console_erp(self, mod_count=1):
+
+    def console_erp(self, mod_count=1, prize_roster_sub_table=None):
         """
         :description: 控制台推送订单和回写物流
         :param mod_count: 单表队列数
+        :param prize_roster_sub_table: 中奖记录扩展表名
         :return: 
         :last_editors: HuangJianYi
         """
         for i in range(mod_count):
 
-            t = threading.Thread(target=self.process_order_push, args=[i, mod_count])
+            t = threading.Thread(target=self.process_order_push, args=[i, mod_count, True, prize_roster_sub_table])
             t.start()
 
             j = threading.Thread(target=self.process_order_pull, args=[i, mod_count])
             j.start()
 
-    def process_order_push(self, mod_value, mod_count, is_loop = True):
+    def process_order_push(self, mod_value, mod_count, is_loop=True, prize_roster_sub_table=""):
         """
         :description: 处理订单推送到遁甲系统
         :param mod_value: 当前队列值
         :param mod_count: 队列数
         :param is_loop: 是否循环
+        :param prize_roster_sub_table: 中奖记录扩展表名
         :return: 
         :last_editors: HuangJianYi
         """
@@ -66,7 +69,7 @@ class ErpConsoleModel():
                         try:
                             erp_relation_model.update_table("sync_date=%s", "id=%s", params=[TimeHelper.get_now_format_time(), erp_relation_dict["id"]])
                             prize_order_model = PrizeOrderModel()
-                            prize_roster_model = PrizeRosterModel()
+                            prize_roster_model = PrizeRosterModel(sub_table=prize_roster_sub_table)
                             condition = "app_id=%s and order_status=0 and sync_status=0"
                             params = [erp_relation_dict["app_id"]]
                             record_count = prize_order_model.get_total(condition, params=params)
@@ -169,7 +172,7 @@ class ErpConsoleModel():
         """
         return request_params
 
-    def process_order_pull(self, mod_value, mod_count,process_type=1):
+    def process_order_pull(self, mod_value, mod_count, process_type=1):
         """
         :description: 处理订单拉取，同步物流信息
         :param mod_value: 当前队列值
