@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2022-11-24 17:21:09
+@LastEditTime: 2022-11-25 14:24:43
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -85,7 +85,6 @@ class StatConsoleModel():
                 if len(stat_queue_list) > 0:
                     for stat_queue in stat_queue_list:
                         try:
-                            stat_log_model = StatLogModel(db_transaction=db_transaction)
                             stat_report_model = StatReportModel(db_transaction=db_transaction)
                             stat_orm = stat_orm_model.get_cache_entity("((act_id=%s and module_id=%s) or (act_id=0 and module_id=0)) and key_name=%s", params=[stat_queue.act_id, stat_queue.module_id, stat_queue.key_name])
                             if not stat_orm:
@@ -95,6 +94,8 @@ class StatConsoleModel():
                             create_day_int = int(create_date.strftime('%Y%m%d'))
                             create_month_int = int(create_date.strftime('%Y%m'))
                             create_year_int = int(create_date.strftime('%Y'))
+                            stat_config = config.get_value("stat_config", {})
+                            stat_log_model = StatLogModel(db_transaction=db_transaction, sub_table=SevenHelper.get_sub_table(stat_orm.id, stat_config.get("statlog_subtable_num", 0)))
                             is_add = True
                             if stat_orm.repeat_type > 0:
                                 if stat_orm.repeat_type == 2:
@@ -181,7 +182,6 @@ class StatConsoleModel():
                     continue
                 try:
                     stat_queue_dict = SevenHelper.json_loads(stat_queue_json)
-                    stat_log_model = StatLogModel(db_transaction=db_transaction)
                     stat_report_model = StatReportModel(db_transaction=db_transaction)
                     stat_orm = stat_orm_model.get_cache_entity("((act_id=%s and module_id=%s) or (act_id=0 and module_id=0)) and key_name=%s", params=[stat_queue_dict["act_id"], stat_queue_dict["module_id"], stat_queue_dict["key_name"]])
                     if not stat_orm:
@@ -191,6 +191,8 @@ class StatConsoleModel():
                     create_day_int = int(create_date.strftime('%Y%m%d'))
                     create_month_int = int(create_date.strftime('%Y%m'))
                     create_year_int = int(create_date.strftime('%Y'))
+                    stat_config = config.get_value("stat_config", {})
+                    stat_log_model = StatLogModel(db_transaction=db_transaction, sub_table=SevenHelper.get_sub_table(stat_orm.id, stat_config.get("statlog_subtable_num", 0)))
                     is_add = True
                     if stat_orm.repeat_type > 0:
                         if stat_orm.repeat_type == 2:
