@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-06-02 14:32:40
-@LastEditTime: 2022-10-13 13:45:18
+@LastEditTime: 2022-10-27 17:29:10
 @LastEditors: HuangJianYi
 :description: 枚举类
 """
@@ -15,7 +15,7 @@ class OperationType(Enum):
     """
     :description: 用户操作日志类型
     """
-    add = 1 #添加
+    add = 1 #新增
     update = 2 #编辑
     delete = 3 #删除
     review = 4 #还原
