@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 09:44:36
-@LastEditTime: 2022-07-15 16:57:42
+@LastEditTime: 2022-10-17 14:07:22
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -49,7 +49,7 @@ class IpBaseModel():
             dependency_key_list.append(DependencyKey.ip_type_list(act_id))
         IpTypeModel().delete_dependency_key(dependency_key_list, delay_delete_time)
 
-    def save_ip_info(self, app_id,act_id,ip_id,ip_name,ip_pic,show_pic,sort_index,is_release,ip_type,ip_summary):
+    def save_ip_info(self, app_id,act_id,ip_id,ip_name,ip_pic,show_pic,sort_index,is_release,ip_type,ip_summary,mode_type=0,ip_config_json=None):
         """
         :description: 保存ip信息
         :param app_id：应用标识
@@ -62,6 +62,8 @@ class IpBaseModel():
         :param is_release：是否发布
         :param ip_type：ip类型
         :param ip_summary：ip描述
+        :param mode_type：模式类型
+        :param ip_config_json：ip配置
         :return
         :last_editors: HuangJianYi
         """
@@ -96,6 +98,9 @@ class IpBaseModel():
         ip_info.ip_summary = ip_summary
         ip_info.sort_index = sort_index
         ip_info.is_release = is_release
+        ip_info.mode_type = mode_type
+        if ip_config_json != None:
+            ip_info.ip_config_json = ip_config_json
         ip_info.modify_date = SevenHelper.get_now_datetime()
         if is_add:
             ip_info.create_date = ip_info.modify_date
@@ -166,6 +171,7 @@ class IpBaseModel():
         del_date = SevenHelper.get_now_datetime()
         invoke_result_data.success = ip_info_model.update_table("is_del=%s,is_release=%s,modify_date=%s,del_date=%s", "id=%s", [is_del, is_release, del_date, del_date, ip_id])
         self._delete_ip_info_dependency_key(ip_info_dict["act_id"],ip_id)
+        invoke_result_data.data = ip_info_dict
         return invoke_result_data
 
     def release_ip_info(self,app_id,ip_id,is_release):
@@ -185,12 +191,13 @@ class IpBaseModel():
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "ip信息不存在"
             return invoke_result_data
-
-        invoke_result_data.success = ip_info_model.update_table("is_release=%s", "id=%s", [is_release, ip_id])
+        modify_date = SevenHelper.get_now_datetime()
+        invoke_result_data.success = ip_info_model.update_table("is_release=%s,modify_date=%s", "id=%s", [is_release, modify_date, ip_id])
         self._delete_ip_info_dependency_key(ip_info_dict["act_id"],ip_id)
+        invoke_result_data.data = ip_info_dict
         return invoke_result_data
 
-    def save_ip_type(self,app_id,act_id,ip_type_id,type_name,sort_index,is_release):
+    def save_ip_type(self,app_id,act_id,ip_type_id,type_name,sort_index,is_release,type_pic=""):
         """
         :description: 保存ip类型
         :param app_id：应用标识
@@ -199,6 +206,7 @@ class IpBaseModel():
         :param type_name：类型名称
         :param sort_index：排序
         :param is_release：是否发布
+        :param type_pic：类型图片
         :return
         :last_editors: HuangJianYi
         """
@@ -227,6 +235,7 @@ class IpBaseModel():
         ip_type.app_id = app_id
         ip_type.act_id = act_id
         ip_type.type_name = type_name
+        ip_type.type_pic = type_pic
         ip_type.sort_index = sort_index
         ip_type.is_release = is_release
         ip_type.modify_date = SevenHelper.get_now_datetime()
@@ -291,7 +300,8 @@ class IpBaseModel():
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "ip信息不存在"
             return invoke_result_data
-
-        invoke_result_data.success = ip_type_model.update_table("is_release=%s", "id=%s", [is_release, ip_type_id])
+        modify_date = SevenHelper.get_now_datetime()
+        invoke_result_data.success = ip_type_model.update_table("is_release=%s,modify_date=%s", "id=%s", [is_release, modify_date, ip_type_id])
         self._delete_ip_type_dependency_key(ip_type_dict["act_id"],ip_type_id)
+        invoke_result_data.data = ip_type_dict
         return invoke_result_data
\ No newline at end of file
