@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2022-11-21 17:25:35
+@LastEditTime: 2022-11-28 11:01:57
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -183,7 +183,7 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "acquire_lock"
             invoke_result_data.error_message = "请求超时,请稍后再试"
             return invoke_result_data
-        
+
         user_account = None
         user_account_model = UserAccountModel(context=self.context)
         user_info = None
@@ -292,6 +292,10 @@ class UserBaseModel(FrameBaseModel):
             invoke_result_data.error_code = "param_error"
             invoke_result_data.error_message = "参数不能为空或等于0"
             return invoke_result_data
+        
+        # 进行授权，有头像没昵称，则给默认的昵称
+        if avatar and not user_nick:
+            user_nick = "未知"
 
         user_account_model = UserAccountModel(context=self.context)
         user_info_dict = None
